@@ -7,9 +7,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/container/channellist.h
 
@@ -37,6 +35,7 @@ public:
 	Channel& GetChannel(const std::string& name);
 	Channel& GetChannel(channel_map_t::size_type index);
 	bool ChannelExists(const std::string& name) const;
+	bool UserExists(const std::string& nick) const;
 	channel_map_t::size_type GetNumChannels() const;
 
 private:
