@@ -3,24 +3,24 @@
 #ifndef _DOWNLOAD_DATA_H
 #define _DOWNLOAD_DATA_H
 
-#include <string>
+#include <memory>
 #include <vector>
-class CFile;
+
 class Mirror;
 class IDownload;
-typedef void CURL;
+class CurlWrapper;
 
 class DownloadData
 {
 public:
 	DownloadData();
-	~DownloadData();
-	int start_piece;
+
+	int start_piece = 0;
 	std::vector<unsigned int> pieces;
-	CURL* easy_handle; //curl_easy_handle
-	Mirror* mirror; //mirror used
-	IDownload *download;
-	bool got_ranges; //true if headers received from server are fine
+	std::unique_ptr<CurlWrapper> curlw; // curl_easy_handle
+	Mirror* mirror = nullptr;     // mirror used
+	IDownload* download;
+	bool got_ranges = false; // true if headers received from server are fine
 };
 
 #endif
