@@ -5,20 +5,16 @@
 
 #include <string>
 
-class IHash;
 class FileData
 {
 public:
-	FileData();
-	~FileData();
-
 	std::string name;
-	unsigned char md5[16];
-	unsigned char crc32[4];
-	unsigned int size;
-	unsigned int compsize; // compressed size
-	bool download;
-	int mode; // chmod
+	unsigned char md5[16] = {};
+	unsigned char crc32[4] = {};
+	unsigned int size = 0;
+	unsigned int compsize = 0; // compressed size
+	bool download = false;
+	int mode = 0644; // chmod
 };
 
 #endif
