@@ -9,7 +9,6 @@
 #include "Logger.h"
 #include "SevenZipArchive.h"
 #include "ZipArchive.h"
-#include "lib/bencode/bencode.h"
 
 #include <zlib.h>
 #include <string.h>
@@ -27,6 +26,7 @@
 #define SHGFP_TYPE_CURRENT 0
 #endif
 #else
+#include <unistd.h>
 #include <sys/statvfs.h>
 #include <errno.h>
 #endif
@@ -205,7 +205,6 @@ void CFileSystem::Shutdown()
 
 const std::string CFileSystem::getSpringDir()
 {
-	assert(!springdir.empty());
 	if (springdir.empty())
 		(setWritePath(""));
 	return springdir;
@@ -427,76 +426,6 @@ bool CFileSystem::removeDir(const std::string& path)
 	return res;
 }
 
-bool CFileSystem::parseTorrent(const char* data, int size, IDownload* dl)
-{
-	be_node* node = be_decoden(data, size);
-	//#ifdef DEBUG
-	//	be_dump(node);
-	//#endif
-	if (node == nullptr) {
-		LOG_ERROR("couldn't parse torrent");
-		return false;
-	}
-	if (node->type != BE_DICT) {
-		LOG_ERROR("Error in torrent data");
-		be_free(node);
-		return false;
-	}
-
-	be_node* infonode = nullptr;
-	for (int i = 0; node->val.d[i].val; ++i) { // search for a dict with name info
-		if ((node->type == BE_DICT) && (strcmp(node->val.d[i].key, "info") == 0)) {
-			infonode = node->val.d[i].val;
-			break;
-		}
-	}
-	if (infonode == nullptr) {
-		LOG_ERROR("couldn't find info node in be dict");
-		be_free(node);
-		return false;
-	}
-	for (int i = 0; infonode->val.d[i].val; ++i) {
-		// fetch needed data from dict and fill into dl
-		be_node* datanode = infonode->val.d[i].val;
-		switch (datanode->type) {
-			case BE_STR: // current value is a string
-				if ((strcmp("name", infonode->val.d[i].key) == 0) &&
-				    (dl->name.empty())) { // set filename if not already set
-					dl->name = datanode->val.s;
-				} else if (!strcmp("pieces",
-						   infonode->val.d[i].key)) { // hash sum of a piece
-					const int count =
-					    be_str_len(datanode) / 20; // one sha1 sum is 5 * 4 bytes long
-					for (int i = 0; i < count; i++) {
-						struct IDownload::piece piece;
-						const unsigned char* data = (unsigned char*)&datanode->val.s[i * 20];
-						piece.sha = new HashSHA1();
-						if (!piece.sha->Set(data, 20)) {
-							LOG_ERROR("Error setting sha1");
-						}
-						piece.state = IDownload::STATE_NONE;
-						dl->pieces.push_back(piece);
-					}
-				}
-				break;
-			case BE_INT:						     // current value is a int
-				if (strcmp("length", infonode->val.d[i].key) == 0) { // filesize
-					dl->size = datanode->val.i;
-				} else if (!strcmp("piece length",
-						   infonode->val.d[i].key)) { // length of a piece
-					dl->piecesize = datanode->val.i;
-					LOG_DEBUG("dl->piecesize: %d", dl->piecesize);
-				}
-				break;
-			default:
-				break;
-		}
-	}
-	LOG_DEBUG("Parsed torrent data: %s %d", dl->name.c_str(), dl->piecesize);
-	be_free(node);
-	return true;
-}
-
 bool CFileSystem::dumpSDP(const std::string& filename)
 {
 	std::list<FileData> files;
@@ -589,10 +518,13 @@ bool CFileSystem::extract(const std::string& filename,
 
 	const unsigned int num = archive->NumFiles();
 	if (num <= 0) {
+		LOG_WARN("Empty archive:  %s", filename.c_str());
+		delete archive;
 		return false;
 	}
+	std::vector<unsigned char> buf;
 	for (unsigned int i = 0; i < num; i++) {
-		std::vector<unsigned char> buf;
+		buf.clear();
 		std::string name;
 		int size, mode;
 		archive->FileInfo(i, name, size, mode);
@@ -711,7 +643,7 @@ unsigned long CFileSystem::getMBsFree(const std::string& path)
 {
 #ifdef _WIN32
 	ULARGE_INTEGER freespace;
-	BOOL res = GetDiskFreeSpaceEx(s2ws(path).c_str(), &freespace, nullptr, nullptr);
+	BOOL res = GetDiskFreeSpaceExW(s2ws(path).c_str(), &freespace, nullptr, nullptr);
 	if (!res) {
 		LOG_ERROR("Error getting free disk space on %s: %d", path.c_str(), GetLastError());
 		return 0;
