@@ -67,11 +67,11 @@ private:
 
 #define LOCK_UNITSYNC                                  \
 	ScopedTime scopedtime(__FUNCTION__, __LINE__); \
-	boost::mutex::scoped_lock lock_criticalsection(m_lock);
+	std::scoped_lock lock_criticalsection(m_lock);
 
 #else
 #define LOCK_UNITSYNC \
-	boost::mutex::scoped_lock lock_criticalsection(m_lock);
+	std::scoped_lock lock_criticalsection(m_lock);
 #endif // __linux__
 
 
@@ -215,7 +215,7 @@ std::vector<std::string> UnitsyncLib::GetUnitsyncErrors() const
 	}
 }
 
-bool UnitsyncLib::VersionSupports(LSL::GameFeature feature) const
+bool UnitsyncLib::VersionSupports(LSL::GameFeature feature)
 {
 	LOCK_UNITSYNC;
 	switch (feature) {
@@ -360,7 +360,7 @@ MapInfo UnitsyncLib::GetMapInfoEx(int index)
 		bool xset = false;
 		for (int i = 0; i < infos; i++) {
 			auto errors = GetUnitsyncErrors();
-			for (const std::string error : errors) {
+			for (const std::string& error : errors) {
 				LslError("%s", error.c_str());
 			}
 			const std::string& key = Util::SafeString(m_get_info_key(i));
