@@ -3,6 +3,7 @@
 #include "FileSystem/FileSystem.h"
 #include "Logger.h"
 #include "lib/md5/md5.h"
+#include "lib/base64/base64.h"
 #include "lsl/lslutils/platform.h"
 
 #include <string.h>
@@ -308,6 +309,27 @@ void DownloadDisableLogging(bool disableLogging)
 	LOG_DISABLE(disableLogging);
 }
 
+// TODO: Add support for other hash types (SHA1, CRC32, ..?)
+char* CalcHash(const char* str, int size, int type)
+{
+	const unsigned char* hash;
+	MD5_CTX ctx;
+	if (type == 0) {
+		MD5Init(&ctx);
+		MD5Update(&ctx, (unsigned char*)str, size);
+		MD5Final(&ctx);
+		hash = ctx.digest;
+	} else {
+		return nullptr;
+	}
+
+	const std::string encoded = base64_encode(hash, 16);
+	char* ret = (char*)malloc((encoded.size() + 1) * sizeof(char));
+	strncpy(ret, encoded.c_str(), encoded.size());
+	ret[encoded.size()] = '\0';
+	return ret;
+}
+
 void SetAbortDownloads(bool value)
 {
 	IDownloader::SetAbortDownloads(value);
