@@ -6,6 +6,7 @@
 #include <wx/choice.h>
 #include <wx/event.h>
 #include <wx/intl.h>
+#include <wx/log.h>
 #include <wx/regex.h>
 #include <wx/sizer.h>
 #include <wx/statbox.h>
@@ -240,7 +241,7 @@ BattleListFilter::BattleListFilter(wxWindow* parent, wxWindowID id, BattleListTa
 
 
 	m_filter_host_edit = new wxTextCtrl(this, BATTLE_FILTER_HOST_EDIT, f_values.host, wxDefaultPosition, wxDefaultSize, 0 | wxSIMPLE_BORDER);
-	m_filter_host_edit->SetFont(wxFont(wxNORMAL_FONT->GetPointSize(), 70, 90, 90, false, wxEmptyString));
+	m_filter_host_edit->SetFont(wxFont(wxNORMAL_FONT->GetPointSize(), wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL, false, wxEmptyString));
 	m_filter_host_edit->SetMinSize(wxSize(220, -1));
 	m_filter_host_text = new wxStaticText(this, wxID_ANY, _("Host:"));
 	m_filter_host_text->Wrap(-1);
@@ -451,7 +452,8 @@ bool BattleListFilter::FilterBattle(IBattle& battle)
 							break;
 						}
 					}
-			} catch (...) {
+			} catch (const std::exception& e) {
+				wxLogWarning(_T("Exception: %s"), e.what());
 			}
 		}
 
@@ -526,7 +528,8 @@ bool BattleListFilter::FilterBattle(IBattle& battle)
 				   m_filter_host_edit->GetValue(),
 				   m_filter_host_expression))
 			return false;
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 
 	//Map:
@@ -536,7 +539,7 @@ bool BattleListFilter::FilterBattle(IBattle& battle)
 		return false;
 
 	//Game:
-	if (!StringMatches(TowxString(battle.GetHostGameName()),
+	if (!StringMatches(TowxString(battle.GetHostGameNameAndVersion()),
 			   m_filter_game_edit->GetValue(),
 			   m_filter_game_expression))
 		return false;
