@@ -9,6 +9,7 @@
 #include <wx/dir.h>
 #include <wx/filename.h>
 #include <wx/listctrl.h>
+#include <wx/log.h>
 #include <wx/sizer.h>
 #include <wx/statline.h>
 #include <wx/stattext.h>
@@ -23,6 +24,12 @@
 #include "utils/conversion.h"
 #include "utils/lslconversion.h"
 
+static const char *banned_AIs[] = {
+	"AAI", "CircuitAI", "CppTestAI",
+	"E323AI", "KAIK", "RAI", "Shard",
+	"NullAI", "NullJavaAI", "NullOOJavaAI", "HughAI"
+};
+
 BEGIN_EVENT_TABLE(AddBotDialog, wxDialog)
 EVT_BUTTON(ADDBOT_CANCEL, AddBotDialog::OnClose)
 EVT_BUTTON(ADDBOT_ADD, AddBotDialog::OnAddBot)
@@ -138,7 +145,7 @@ wxString AddBotDialog::GetNick()
 
 wxString AddBotDialog::Get(const std::string& section)
 {
-	const auto sel = m_ai->GetSelection();
+	const auto sel = GetSelectedAIType();
 	const auto infos = LSL::usync().GetAIInfos(sel);
 	const auto namepos = LSL::Util::IndexInSequence(infos, section);
 	if (namepos == LSL::lslNotFound)
@@ -156,9 +163,9 @@ wxString AddBotDialog::GetAIVersion()
 	return Get("version");
 }
 
-int AddBotDialog::GetAIType()
+int AddBotDialog::GetSelectedAIType()
 {
-	return m_ai->GetSelection();
+	return m_valid_ai_index_map.at (m_ai->GetSelection());
 }
 
 wxString AddBotDialog::RefineAIName(const wxString& name)
@@ -179,25 +186,54 @@ wxString AddBotDialog::GetAiRawName()
 {
 	//    if ( m_ais.GetCount() < m_ai->GetSelection() )
 	//        return wxEmptyString;
-	return m_ais[m_ai->GetSelection()];
+	return m_ais [GetSelectedAIType()];
+}
+
+static bool IsHiddenAI(const std::string& AINameVersion)
+{
+
+	for (unsigned int j = 0; j < sizeof (banned_AIs) / sizeof(char *); ++j) {
+		const char *ai_str = banned_AIs[j];
+		if (std::string::npos != AINameVersion.find(ai_str)) {
+			return true;
+		}
+	}
+	return false;
+
 }
 
 void AddBotDialog::ReloadAIList()
 {
+	LSL::StringVector ais;
 	try {
-		m_ais = lslTowxArrayString(LSL::usync().GetAIList(m_battle.GetHostGameName()));
-	} catch (...) {
+		ais = LSL::usync().GetAIList(m_battle.GetHostGameNameAndVersion());
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception while loading AIs: %s"), e.what());
 	}
 
+	// m_ai is the wxChoice display list
 	m_ai->Clear();
-	for (unsigned int i = 0; i < m_ais.GetCount(); i++)
-		m_ai->Append(RefineAIName(m_ais[i]));
-	if (m_ais.GetCount() > 0) {
-		m_ai->SetStringSelection(sett().GetLastAI());
-		if (m_ai->GetStringSelection() == wxEmptyString)
-			m_ai->SetSelection(0);
-	} else {
+	// m_ais is a wxArrayString of all AIs, even blocked ones.
+	m_ais.clear();
+	m_valid_ai_index_map.clear();
+	for (unsigned int i = 0; i < ais.size(); ++i) {
+		const std::string& AINameVersion = ais.at(i);
+		const bool matched = IsHiddenAI(AINameVersion);
+
+		wxString wxAINV (AINameVersion);
+		m_ais.Add(wxAINV);
+		if (!matched || (sett().GetUserLevel() >= Settings::UserLevel::Professional)) {
+			m_ai->Append(RefineAIName(wxAINV));
+			m_valid_ai_index_map.push_back(i);
+		}
+	}
+	if (m_ai->GetCount() <= 0) {
 		customMessageBox(SL_MAIN_ICON, _("No AI bots found in your Spring installation."), _("No bot-libs found"), wxOK);
+		return;
+	}
+	m_ai->SetStringSelection(sett().GetLastAI());
+	if (m_ai->GetStringSelection() == wxEmptyString) {
+		m_ai->SetSelection(0);
 	}
 	m_add_btn->Enable(m_ai->GetStringSelection() != wxEmptyString);
 	ShowAIInfo();
@@ -231,7 +267,7 @@ void AddBotDialog::ShowAIInfo()
 {
 	m_add_btn->Enable(m_ai->GetStringSelection() != wxEmptyString);
 	m_ai_infos_lst->DeleteAllItems();
-	const wxArrayString info = lslTowxArrayString(LSL::usync().GetAIInfos(GetAIType()));
+	const wxArrayString info = lslTowxArrayString(LSL::usync().GetAIInfos(GetSelectedAIType()));
 	int count = info.GetCount();
 	for (int i = 0; i < count; i = i + 3) {
 		long index = m_ai_infos_lst->InsertItem(i, info[i]);
@@ -249,7 +285,7 @@ void AddBotDialog::ShowAIOptions()
 {
 	m_opts_list->DeleteAllItems();
 	m_opt_list_map.clear();
-	m_battle.CustomBattleOptions().loadAIOptions(m_battle.GetHostGameName(), GetAIType(), STD_STRING(GetNick()));
+	m_battle.CustomBattleOptions().loadAIOptions(m_battle.GetHostGameNameAndVersion(), GetSelectedAIType(), STD_STRING(GetNick()));
 	AddMMOptionsToList(0, m_battle.CustomBattleOptions().GetAIOptionIndex(STD_STRING(GetNick())));
 	m_opts_list->SetColumnWidth(0, wxLIST_AUTOSIZE);
 	m_opts_list->SetColumnWidth(1, wxLIST_AUTOSIZE);
