@@ -4,9 +4,7 @@
 #define MAINTORRENTTAB_H
 
 #include <wx/scrolwin.h>
-#include <wx/timer.h>
 #include <map>
-
 class wxStaticText;
 class wxButton;
 class DownloadDataViewCtrl;
@@ -26,7 +24,16 @@ public:
 	MainDownloadTab(wxWindow* parent);
 	~MainDownloadTab();
 
-	void OnUpdate(wxTimerEvent& /*event*/);
+private:
+	void OnCancelButton(wxCommandEvent& event);
+	void OnDownloadDialog(wxCommandEvent& event);
+	void OnDLWidgets(wxCommandEvent& event);
+	void OnClearFinished(wxCommandEvent& event);
+
+	void OnDownloadFailed(wxCommandEvent& /*event*/);
+	void OnUnitsyncReloaded(wxCommandEvent& /*event*/);
+
+	void UpdateDownloadDir();
 
 private:
 	enum {
@@ -39,32 +46,19 @@ private:
 		ID_DOWNLOAD_DIALOG,
 		ID_BUTTON_CLEAR,
 		ID_BUTTON_WIDGETS,
-		ID_TIMER
 	};
 
 	wxButton* m_but_cancel;
 	wxButton* m_but_clear;
 	DownloadDataViewCtrl* m_DownloadDataView;
 	WidgetDownloadDialog* m_widgets_dialog;
-
-	void OnCancelButton(wxCommandEvent& event);
-	void OnDownloadDialog(wxCommandEvent& event);
-	void OnDLWidgets(wxCommandEvent& event);
-	void OnClearFinished(wxCommandEvent& event);
-
-	void OnNewDownloadStarted(wxCommandEvent& event);
-	void OnDownloadComplete(wxCommandEvent& event);
-
+	wxStaticText* m_currDownloadDirText;
 	wxBoxSizer* m_main_sizer;
-
-private:
-	//(*Handlers(MainTorrentTab)
-	//*)
-
-	DECLARE_EVENT_TABLE()
 	ContentDownloadDialog* m_download_dialog;
 	wxButton* m_but_download;
-	wxTimer* timer;
+
+private:
+	DECLARE_EVENT_TABLE()
 };
 
 #endif
