@@ -12,7 +12,7 @@ class OfflineServer : public TASServer
 public:
 	OfflineServer();
 	~OfflineServer();
-	void Connect(const std::string& servername, const std::string& addr, const int port) override;
+	void Connect(const ServerLoginInfo&) override;
 	void SendCmd(const std::string& command, const std::string& param, bool relay) override;
 	void Login() override
 	{
