@@ -1,6 +1,7 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
 
-#include <windows.h>
+#include <windef.h>
+#include <mmsystem.h>
 #include "ring_sound.h"
 #include "pm_sound.h"
 #include "alsound.h"
@@ -12,16 +13,16 @@ ALsound::ALsound()
 
 ALsound::~ALsound()
 {
-	PlaySound(NULL, 0, 0); // STOP ANY PLAYING SOUND
+	PlaySoundA(NULL, 0, 0); // STOP ANY PLAYING SOUND
 }
 
 void ALsound::ring()
 {
-	PlaySound((LPCSTR)ring_sound_data, NULL, SND_MEMORY | SND_ASYNC);
+	PlaySoundA((LPCSTR)ring_sound_data, NULL, SND_MEMORY | SND_ASYNC);
 }
 void ALsound::pm()
 {
-	PlaySound((LPCSTR)pm_sound_data, NULL, SND_MEMORY | SND_ASYNC);
+	PlaySoundA((LPCSTR)pm_sound_data, NULL, SND_MEMORY | SND_ASYNC);
 }
 
 ALsound& slsound()
