@@ -551,10 +551,8 @@ std::string Spring::WriteScriptTxt(IBattle& battle) const
 
 	tdf.AppendLineBreak();
 
-	unsigned int maxiter = std::max(NumUsers, battle.GetLastRectIdx() + 1);
 	std::set<int> parsedallys;
-	for (unsigned int i = 0; i < maxiter; i++) {
-
+	for (unsigned int i = 0; i < NumUsers; i++) {
 		User& usr = battle.GetUser(i);
 		UserBattleStatus& status = usr.BattleStatus();
 		BattleStartRect sr = battle.GetStartRect(i);
@@ -566,6 +564,10 @@ std::string Spring::WriteScriptTxt(IBattle& battle) const
 		if (parsedallys.find(ally) != parsedallys.end())
 			continue; // skip duplicates
 		sr = battle.GetStartRect(ally);
+
+		if (!sr.IsOk()) {
+			wxLogWarning("No Battle Start rect for Team %d Ally %d ",status.team, ally);
+		}
 		parsedallys.insert(ally);
 
 		tdf.EnterSection(stdprintf("ALLYTEAM%d", ally));
