@@ -41,10 +41,9 @@ public:
 	// Overloaded functions from Server
 	bool ExecuteSayCommand(const std::string& cmd) override;
 
-	void Register(const std::string& servername, const std::string& host, const int port, const std::string& nick, const std::string& password) override;
-	void AcceptAgreement() override;
+	void Register(const ServerLoginInfo& server) override;
+	void AcceptAgreement(const std::string&) override;
 
-	void Connect(const std::string& servername, const std::string& addr, const int port) override;
 	void Disconnect() override;
 	bool IsConnected() override;
 
@@ -120,6 +119,7 @@ public:
 	void SendScriptToProxy(const std::string& script) override;
 
 private:
+	void Connect(const ServerLoginInfo& server) override;
 	void SendUdpSourcePort(int udpport);
 	void SendNATHelperInfos(const std::string& username, const std::string& ip, int port);
 
@@ -128,25 +128,22 @@ private:
 	{
 		return m_se;
 	}
-	LSL::StringSet GetSubscriptions() override
-	{
-		return m_subscriptions;
-	}
 	// TASServer specific functions
 	void ExecuteCommand(const std::string& cmd, const std::string& inparams, int replyid = -1);
 
 	void HandlePong(int replyid);
 
 
-	bool IsPasswordHash(const std::string& pass) const;
-	std::string GetPasswordHash(const std::string& pass) const;
+	bool IsPasswordHash(const std::string& pass) const override;
+	std::string GetPasswordHash(const std::string& pass) const override;
 
-	void SetRelayIngamePassword(const User& user);
+	void SetRelayIngamePassword(const User& user) override;
 
 	void OnConnected() override;
-	void OnDisconnected() override;
+	void OnDisconnected(wxSocketError err) override;
 	void OnDataReceived() override;
 	void OnError(const std::string& err) override;
+	void OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint) override;
 
 	void UDPPing(); /// used for nat travelsal
 	/// generic udp "ping" function
@@ -169,24 +166,25 @@ private:
 	virtual void SendCmd(const std::string& command, const std::string& param, bool relay);
 
 
-	void RelayCmd(const std::string& command, const std::string& param = "");
-	void Notify();
+	void RelayCmd(const std::string& command, const std::string& param = "") override;
+	void Notify() override;
+	bool IsCurrentBattle(int battle_id);
+	void ParseJson(const std::string& jsonstr);
 
 	//! @brief Struct used internally by the TASServer class to calculate ping roundtimes.
-	struct TASPingListItem
-	{
+	struct TASPingListItem {
 		int id;
 		wxLongLong t;
 	};
 
 	CRC m_crc;
+	const std::string GetSys();
 
 	ServerEvents* m_se;
 	Socket* m_sock;
 
 	double m_ser_ver;
 	LSL::StringVector m_relay_host_manager_list;
-	LSL::StringSet m_subscriptions;
 
 	std::string m_last_denied;
 	bool m_connected;
@@ -213,16 +211,17 @@ private:
 
 	std::string m_agreement;
 
-	std::string m_addr;
 	std::string m_delayed_open_command;
 
 	bool m_do_finalize_join_battle;
+	bool m_do_register;
 	int m_finalize_join_battle_id;
 	std::string m_finalize_join_battle_pw;
 
 	std::string m_current_chan_name_mutelist;
 	std::string m_relay_host_bot;
 	std::string m_relay_host_manager;
+	std::string m_supported_spring_version;
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_TASSERVER_H
