@@ -10,8 +10,7 @@
 #include "chatlog.h"
 #include "testingstuff/silent_logger.h"
 
-struct TestInitializer
-{
+struct TestInitializer {
 	TestInitializer()
 	{
 		InitWxLogger();
