@@ -4,9 +4,8 @@
 #define SPRINGLOBBY_VERSION_H
 
 #include <string>
-
-const std::string getSpringlobbyVersion();
-const std::string getSpringlobbyAgent();
-const std::string getSpringlobbyName(bool lowercase = false);
+const std::string GetSpringlobbyVersion();
+const std::string GetSpringlobbyAgent();
+const std::string GetSpringlobbyName(bool lowercase = false);
 
 #endif
