@@ -1,15 +1,14 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #include "wxTranslationHelper.h"
+
 #include <wx/dir.h>
 #include <wx/filename.h>
-#include <wx/log.h>
 #include <wx/intl.h>
+#include <wx/log.h>
 
-#include "utils/slconfig.h"
-#include "utils/slpaths.h"
-#include "utils/conversion.h"
 #include "gui/customdialogs.h"
+#include "utils/conversion.h"
+#include "utils/slconfig.h"
 
 SLCONFIG("/General/LanguageID", (long)wxLANGUAGE_DEFAULT, "Language ID");
 
@@ -18,13 +17,16 @@ wxTranslationHelper::wxTranslationHelper(const wxString& catalog, const wxString
     , catalogname(catalog)
     , m_Locale(NULL)
 {
-	if (search_path.IsEmpty()) {
-		m_SearchPath = TowxString(SlPaths::GetExecutableFolder());
-	}
+	wxLogInfo(_T("Using LocalePath %s"), m_SearchPath.c_str());
 	long language = cfg().ReadLong(_T("/General/LanguageID"));
-	if (!Load(language)) { //fallback when something went wrong
-		int localeid = wxLocale::GetSystemLanguage();
-		Load(localeid);
+	if (Load(language))
+		return;
+	//fallback when something went wrong
+	wxLogWarning("Couldn't load locale %ld, fallback to default", language);
+	language = wxLocale::GetSystemLanguage();
+	if (Load(language)) {
+		cfg().Write(_T( "/General/LanguageID" ), language);
+		cfg().SaveFile(); //instant save to config
 	}
 }
 
@@ -51,12 +53,13 @@ bool wxTranslationHelper::Load(int language)
 			if (m_Locale) {
 				wxDELETE(m_Locale);
 			}
-			m_Locale = new wxLocale;
-			m_Locale->Init(identifiers[i]);
+			m_Locale = new wxLocale(identifiers[i]);
+			//bool res = m_Locale->Init(identifiers[i]);
 			m_Locale->AddCatalogLookupPathPrefix(m_SearchPath);
 			m_Locale->AddCatalog(catalogname);
-			m_Locale->AddCatalog(_T("wxstd"));
-			return true;
+			//m_Locale->AddCatalog(_T("wxstd"));
+			wxLogMessage(wxString::Format(_("Loaded locale %s %d %s %s"), m_Locale->GetName().c_str(), m_Locale->IsOk(), m_SearchPath.c_str(), m_Locale->GetCanonicalName().c_str()));
+			return m_Locale->IsOk();
 		}
 	}
 	return false;
@@ -82,17 +85,17 @@ void wxTranslationHelper::GetInstalledLanguages(wxArrayString& names, wxArrayLon
 
 	for (bool cont = dir.GetFirst(&filename, wxEmptyString, wxDIR_DIRS); cont; cont = dir.GetNext(&filename)) {
 		langinfo = wxLocale::FindLanguageInfo(filename);
-		if (langinfo != NULL) {
-			wxString mo_file = dir.GetName() + wxFileName::GetPathSeparator() + filename + wxFileName::GetPathSeparator() + _T("LC_MESSAGES") + wxFileName::GetPathSeparator() + catalogname + wxT(".mo");
-			wxLogInfo(_("SEARCHING FOR %s"), mo_file.GetData());
-			if (wxFileExists(mo_file)) {
-				if (langinfo->Language == localeid)
-					names.Add(langinfo->Description + _(" (Default)"));
-				else
-					names.Add(langinfo->Description);
-				identifiers.Add(langinfo->Language);
-			}
-		}
+		if (langinfo == nullptr)
+			continue;
+		wxString mo_file = dir.GetName() + wxFileName::GetPathSeparator() + filename + wxFileName::GetPathSeparator() + _T("LC_MESSAGES") + wxFileName::GetPathSeparator() + catalogname + wxT(".mo");
+		wxLogInfo(_("SEARCHING FOR %s"), mo_file.GetData());
+		if (!wxFileExists(mo_file))
+			continue;
+		if (langinfo->Language == localeid)
+			names.Add(langinfo->Description + _(" (Default)"));
+		else
+			names.Add(langinfo->Description);
+		identifiers.Add(langinfo->Language);
 	}
 }
 
